@@ -4,7 +4,6 @@ import getpass
 from argparse import ArgumentParser
 
 import yaml
-
 from deepchain.cli import BaseCLICommand
 
 from .apps_utils import _create_config_file, _create_deechpain_folder
@@ -17,7 +16,7 @@ def auth_command_factory(args):
 class AuthCommand(BaseCLICommand):
     @staticmethod
     def register_subcommand(parser: ArgumentParser):
-        login_parser = parser.add_parser(name="login", help="login to deepchain")
+        login_parser = parser.add_parser(name="login", help="login to deepchain")  # type: ignore
         login_parser.set_defaults(func=auth_command_factory)
 
     def run(self):
