@@ -10,4 +10,4 @@ EXTENSIONS = [
     ".pickle",
 ]
 
-TAGS_KEY = ["tasks", "libraries", "embeddings", "datasets", "cuda"]
+TAGS_KEY = ["tasks", "libraries", "embeddings", "datasets", "device"]
